package com.fairphone.updater.data;

import android.text.TextUtils;

import java.util.HashMap;
import java.util.Map;

public class Message implements Comparable<Message> {

    private static final String TAG = Message.class.getSimpleName();

    public static final String DEFAULT_MESSAGE_LANG = "en";

    private String mId;
    private final Map<String, String> mTitleMap;
    private final Map<String, String> mContentMap;
    private final Map<String, String> mBigTextMap;
    private String mUrl;
    private int mExpiryDate;
    private boolean mPersistent;
    private boolean mAutoCancel = true;

    public Message() {
        mTitleMap = new HashMap<>();
        mContentMap = new HashMap<>();
        mBigTextMap = new HashMap<>();
    }

    public String getId() {
        return mId;
    }

    public void setId(String id) {
        mId = id;
    }

    public String getTitle(String language) {
        String title = "";

        if (mTitleMap.containsKey(language)) {
            title = mTitleMap.get(language);
        }
        else if (mTitleMap.containsKey(DEFAULT_MESSAGE_LANG)) {
            title = mTitleMap.get(DEFAULT_MESSAGE_LANG);
        }
        return TextUtils.isEmpty(title) ? "" : title;
    }

    public void setTitle(String language, String title) {
        mTitleMap.put(language.toLowerCase(), title);
    }

    public String getContent(String language) {
        String content = "";

        if (mContentMap.containsKey(language)) {
            content = mContentMap.get(language);
        }
        else if (mContentMap.containsKey(DEFAULT_MESSAGE_LANG)) {
            content = mContentMap.get(DEFAULT_MESSAGE_LANG);
        }
        return TextUtils.isEmpty(content) ? "" : content;
    }

    public void setContent(String language, String content) {
        mContentMap.put(language.toLowerCase(), content);
    }

    public String getBigText(String language) {
        String bigText = "";

        if (mBigTextMap.containsKey(language)) {
            bigText = mBigTextMap.get(language);
        }
        else if (mBigTextMap.containsKey(DEFAULT_MESSAGE_LANG)) {
            bigText = mBigTextMap.get(DEFAULT_MESSAGE_LANG);
        }
        return TextUtils.isEmpty(bigText) ? "" : bigText;
    }

    public void setBigText(String language, String bigText) {
        mBigTextMap.put(language.toLowerCase(), bigText);
    }

    public String getUrl() {
        return mUrl;
    }

    public void setUrl(String url) {
        mUrl = url;
    }

    public int getExpiryDate() {
        return mExpiryDate;
    }

    public void setExpiryDate(int expiryDate) {
        mExpiryDate = expiryDate;
    }

    public boolean isPersistent() {
        return mPersistent;
    }

    public void setPersistent(boolean persistent) {
        mPersistent = persistent;
    }

    public boolean isAutoCancel() {
        return mAutoCancel;
    }

    public void setAutoCancel(boolean autoCancel) {
        mAutoCancel = autoCancel;
    }

    @Override
    public int compareTo(Message another) {
        int retVal;
        if (another != null) {
            if (!this.getId().equals(another.getId())) {
                retVal = 1;
            } else if (this.getId() == another.getId()) {
                retVal = 0;
            } else {
                retVal = -1;
            }
        } else {
            retVal = 1;
        }
        return retVal;
    }
}
